@@ -26,18 +26,16 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::SearchGoogleAdsIterator;
-use Google::Ads::GoogleAds::V16::Enums::CriterionTypeEnum qw(KEYWORD);
+use Google::Ads::GoogleAds::V17::Enums::CriterionTypeEnum qw(KEYWORD);
 use
-  Google::Ads::GoogleAds::V16::Services::GoogleAdsService::SearchGoogleAdsRequest;
+  Google::Ads::GoogleAds::V17::Services::GoogleAdsService::SearchGoogleAdsRequest;
 use
-  Google::Ads::GoogleAds::V16::Services::SharedCriterionService::SharedCriterionOperation;
+  Google::Ads::GoogleAds::V17::Services::SharedCriterionService::SharedCriterionOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
 use Cwd qw(abs_path);
 
-use constant PAGE_SIZE => 1000;
-
 # The following parameter(s) should be provided to run the example. You can
 # either specify these by changing the INSERT_XXX_ID_HERE values below, or on
 # the command line.
@@ -61,11 +59,10 @@ sub find_and_remove_criteria_from_shared_set {
     "WHERE campaign.id = $campaign_id";
 
   my $search_request =
-    Google::Ads::GoogleAds::V16::Services::GoogleAdsService::SearchGoogleAdsRequest
+    Google::Ads::GoogleAds::V17::Services::GoogleAdsService::SearchGoogleAdsRequest
     ->new({
       customerId => $customer_id,
-      query      => $search_query,
-      pageSize   => PAGE_SIZE
+      query      => $search_query
     });
 
   my $google_ads_service = $api_client->GoogleAdsService();
@@ -99,11 +96,10 @@ sub find_and_remove_criteria_from_shared_set {
     join(',', @$shared_set_ids);
 
   $search_request =
-    Google::Ads::GoogleAds::V16::Services::GoogleAdsService::SearchGoogleAdsRequest
+    Google::Ads::GoogleAds::V17::Services::GoogleAdsService::SearchGoogleAdsRequest
     ->new({
       customerId => $customer_id,
-      query      => $search_query,
-      pageSize   => PAGE_SIZE
+      query      => $search_query
     });
 
   $iterator = Google::Ads::GoogleAds::Utils::SearchGoogleAdsIterator->new({
@@ -137,7 +133,7 @@ sub find_and_remove_criteria_from_shared_set {
   my $shared_criterion_operations = [];
   foreach my $criterion_resource_name (@$criterion_resource_names) {
     push @$shared_criterion_operations,
-      Google::Ads::GoogleAds::V16::Services::SharedCriterionService::SharedCriterionOperation
+      Google::Ads::GoogleAds::V17::Services::SharedCriterionService::SharedCriterionOperation
       ->new({
         remove => $criterion_resource_name
       });
